==> haskell-retry-0.7.6.2-22-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-retry.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: retry
version: 0.7.6.2
id: retry-0.7.6.2-6dbzJbMn5nbDUXXD7qxj6H
key: retry-0.7.6.2-6dbzJbMn5nbDUXXD7qxj6H
license: BSD-3-Clause
copyright: Ozgun Ataman, Soostone Inc
maintainer: ozgun.ataman@soostone.com
author: Ozgun Ataman
homepage: http://github.com/Soostone/retry
synopsis: Retry combinators for monadic actions that may fail
description:
    This package exposes combinators that can wrap arbitrary
    monadic actions. They run the action and potentially retry
    running it with some configurable delay for a configurable
    number of times.
    The purpose is to make it easier to work with IO and
    especially network IO actions that often experience temporary
    failure and warrant retrying of the original action. For
    example, a database query may time out for a while, in which
    case we should hang back for a bit and retry the query instead
    of simply raising an exception.
category: Control
abi: 23f66935379cb83f012379e9d1bc21de
exposed: True
exposed-modules:
    Control.Retry
import-dirs: /usr/lib/ghc-8.4.3/site-local/retry-0.7.6.2
library-dirs: /usr/lib/ghc-8.4.3/site-local/retry-0.7.6.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/retry-0.7.6.2
hs-libraries: HSretry-0.7.6.2-6dbzJbMn5nbDUXXD7qxj6H
depends:
    base-4.11.1.0 data-default-class-0.1.2.0-EBMa9CD2M17D2Emy9Sff6j
    exceptions-0.10.0-7epDYg20HTz9YX9m9nzGfO ghc-prim-0.5.2.0
    random-1.1-9LLJAJa4iQFLJiLXBOBXBV transformers-0.5.5.0
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             data-default-class-0.1.2.0-EBMa9CD2M17D2Emy9Sff6j=64b4bc7e44050b1acf530e79a106effe
             exceptions-0.10.0-7epDYg20HTz9YX9m9nzGfO=87ba3c1011ac70bcfb17ce2e39a2e1bb
             ghc-prim-0.5.2.0=39dc2488936298f474639901f9105eec
             random-1.1-9LLJAJa4iQFLJiLXBOBXBV=8df244958947206247b1dd733653312e
             transformers-0.5.5.0=633c3e5ec737c360775b452ce9aa1e0b
haddock-interfaces: /usr/share/doc/haskell-retry/html/retry.haddock
haddock-html: /usr/share/doc/haskell-retry/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-retry-0.7.6.2-24-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-retry.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: retry
version: 0.7.6.2
id: retry-0.7.6.2-JOlHOnbJZAx4PqMwJohQq4
key: retry-0.7.6.2-JOlHOnbJZAx4PqMwJohQq4
license: BSD-3-Clause
copyright: Ozgun Ataman, Soostone Inc
maintainer: ozgun.ataman@soostone.com
author: Ozgun Ataman
homepage: http://github.com/Soostone/retry
synopsis: Retry combinators for monadic actions that may fail
description:
    This package exposes combinators that can wrap arbitrary
    monadic actions. They run the action and potentially retry
    running it with some configurable delay for a configurable
    number of times.
    The purpose is to make it easier to work with IO and
    especially network IO actions that often experience temporary
    failure and warrant retrying of the original action. For
    example, a database query may time out for a while, in which
    case we should hang back for a bit and retry the query instead
    of simply raising an exception.
category: Control
abi: d3f2414f5ac9e6b5233b68adf5c34486
exposed: True
exposed-modules:
    Control.Retry
import-dirs: /usr/lib/ghc-8.4.3/site-local/retry-0.7.6.2
library-dirs: /usr/lib/ghc-8.4.3/site-local/retry-0.7.6.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/retry-0.7.6.2
hs-libraries: HSretry-0.7.6.2-JOlHOnbJZAx4PqMwJohQq4
depends:
    base-4.11.1.0 data-default-class-0.1.2.0-EBMa9CD2M17D2Emy9Sff6j
    exceptions-0.10.0-7epDYg20HTz9YX9m9nzGfO ghc-prim-0.5.2.0
    random-1.1-9LLJAJa4iQFLJiLXBOBXBV transformers-0.5.5.0
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             data-default-class-0.1.2.0-EBMa9CD2M17D2Emy9Sff6j=64b4bc7e44050b1acf530e79a106effe
             exceptions-0.10.0-7epDYg20HTz9YX9m9nzGfO=87ba3c1011ac70bcfb17ce2e39a2e1bb
             ghc-prim-0.5.2.0=39dc2488936298f474639901f9105eec
             random-1.1-9LLJAJa4iQFLJiLXBOBXBV=8df244958947206247b1dd733653312e
             transformers-0.5.5.0=633c3e5ec737c360775b452ce9aa1e0b
haddock-interfaces: /usr/share/doc/haskell-retry/html/retry.haddock
haddock-html: /usr/share/doc/haskell-retry/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
